pub struct Builder { /* private fields */ }Expand description
Builder for configuring and running the validation code generator.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn file_descriptor_set_bytes(self, bytes: Vec<u8>) -> Self
pub fn file_descriptor_set_bytes(self, bytes: Vec<u8>) -> Self
Set the file descriptor set bytes directly.
Sourcepub fn out_dir(self, path: impl Into<PathBuf>) -> Self
pub fn out_dir(self, path: impl Into<PathBuf>) -> Self
Override the output directory (defaults to OUT_DIR env var).
Sourcepub fn extern_path(
self,
proto_path: impl Into<String>,
rust_path: impl Into<String>,
) -> Self
pub fn extern_path( self, proto_path: impl Into<String>, rust_path: impl Into<String>, ) -> Self
Map a proto package path to a Rust module path.
This is equivalent to prost-build’s extern_path and should match
your prost-build configuration.
Example
prost_protovalidate_build::Builder::new()
.extern_path(".my.package", "::my_crate::my_package");Trait Implementations